@@ -10,6 +10,9 @@ class Api(object):
     def __init__(self):
         self.db_client = DBClient()
 
+    def __del__(self):
+        del self.db_client
+
     def get_node_info(self, ip=None):
         """
         get node information, if ip is None, will get all node information
@@ -78,7 +81,9 @@ class Api(object):
         return self.db_client.benchmark_resource.get_test_state(key)
 
 
-if __name__ == '__main__':
-    API = Api()
-    a = API.get_node_info()
-    print(a)
+# if __name__ == '__main__':
+#     API = Api()
+#     b = API.get_node_info()
+#     c = API.get_node_usage("172.29.131.6")
+#     d = API.get_tests_detail("172.29.130.138")
+#     pass
